package com.ozs.web.controller.accountmanagment;


import com.baomidou.mybatisplus.core.metadata.IPage;
import com.ozs.common.annotation.Log;
import com.ozs.common.core.controller.BaseController;
import com.ozs.common.core.domain.AjaxResult;
import com.ozs.common.enums.BusinessType;
import com.ozs.common.utils.StringUtils;
import com.ozs.entity.BaseVehicleTerminal;
import com.ozs.entity.vo.BaseVehicleTerminalVo;
import com.ozs.service.BaseVehicleTerminalService;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * <p>
 * 机车车载终端信息表 前端控制器
 * </p>
 *
 * @author ozs
 * @since 2023-04-11
 */
@Slf4j
@RestController
@RequestMapping("/baseVehicleTerminal")
public class BaseVehicleTerminalController extends BaseController {

    @Autowired
    private BaseVehicleTerminalService baseVehicleTerminalService;

    /**
     * 车载终端信息表 分页查询
     *
     * @param baseVehicleTerminalVo
     * @return
     */
    @ApiOperation(value = "终端信息表 分页查询")
    @PostMapping("/vehicleTerminalList")
    @Log(title = "车载终端管理", businessType = BusinessType.SELECT)
    public AjaxResult vehicleTerminalList(@RequestBody BaseVehicleTerminalVo baseVehicleTerminalVo) {
        IPage<BaseVehicleTerminal> baseVehicleTerminalIPage = baseVehicleTerminalService.vehicleTerminalList(baseVehicleTerminalVo);
        return AjaxResult.success(baseVehicleTerminalIPage);
    }

    /**
     * 车载终端信息表 详情
     *
     * @param baseVehicleTerminalVo
     * @return
     */
    @ApiOperation(value = "车载终端信息表 详情")
    @PostMapping("/baseVehicleTerminalDetails")
    @Log(title = "车载终端管理", businessType = BusinessType.SELECT)
    public AjaxResult baseVehicleTerminalDetails(@RequestBody BaseVehicleTerminalVo baseVehicleTerminalVo) {
        if (StringUtils.isEmptySunhh(baseVehicleTerminalVo) || StringUtils.isEmptySunhh(baseVehicleTerminalVo.getId())) {
            return AjaxResult.error("车载终端id不能为空！");
        }
        return baseVehicleTerminalService.baseVehicleTerminalDetails(baseVehicleTerminalVo);
    }

    /**
     * 车载终端信息表 新增
     *
     * @param baseVehicleTerminal
     * @return
     */
    @ApiOperation(value = "车载终端信息表 新增")
    @PostMapping("/vehicleTerminalAdd")
    @Log(title = "车载终端管理", businessType = BusinessType.INSERT)
    public AjaxResult vehicleTerminalAdd(@RequestBody BaseVehicleTerminal baseVehicleTerminal) {
        if (StringUtils.isEmptySunhh(baseVehicleTerminal) || StringUtils.isEmptySunhh(baseVehicleTerminal.getTerminalCode())
                || StringUtils.isEmptySunhh(baseVehicleTerminal.getTerminalName())) {
            return AjaxResult.error("车载终端名称、车载终端编码不能为空！");
        }
        return baseVehicleTerminalService.vehicleTerminalAdd(baseVehicleTerminal, getUserId());
    }

    /**
     * 车载终端信息表 修改
     *
     * @param baseVehicleTerminal
     * @return
     */
    @ApiOperation(value = "车载终端信息表 修改")
    @PostMapping("/vehicleTerminalUpdate")
    @Log(title = "车载终端管理", businessType = BusinessType.UPDATE)
    public AjaxResult vehicleTerminalUpdate(@RequestBody BaseVehicleTerminal baseVehicleTerminal) {
        if (StringUtils.isEmptySunhh(baseVehicleTerminal) || StringUtils.isEmptySunhh(baseVehicleTerminal.getId())) {
            return AjaxResult.error("修改ID不能为空！");
        }
        return baseVehicleTerminalService.vehicleTerminalUpdate(baseVehicleTerminal, getUserId());
    }

    /**
     * 车载终端信息表 删除
     *
     * @param ids
     * @return
     */
    @ApiOperation(value = "车载终端信息表 删除")
    @DeleteMapping("/vehicleTerminaleDelete/{ids}")
    @Log(title = "车载终端管理", businessType = BusinessType.DELETE)
    public AjaxResult vehicleDelete(@PathVariable List<Long> ids) {
        if (StringUtils.isEmptySunhh(ids)) {
            return AjaxResult.error("删除ID不能为空！");
        }
        boolean delete = baseVehicleTerminalService.removeByIds(ids);
        if (delete) {
            return AjaxResult.success();
        } else {
            return AjaxResult.error();
        }
    }

    /**
     * 终端信息表 查询
     *
     * @return
     */
    @ApiOperation(value = "终端信息表 查询")
    @PostMapping("/terminalAll")
    @Log(title = "终端信息表 查询", businessType = BusinessType.SELECT)
    public AjaxResult terminalAll() {
        List<BaseVehicleTerminal> list = baseVehicleTerminalService.list();
        return AjaxResult.success(list);
    }

}

